// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	basedal "LAPP_GAAS_GFrame_BACKEND/dao/base"
	dal "LAPP_GAAS_GFrame_BACKEND/dao/jit"
	logDal "LAPP_GAAS_GFrame_BACKEND/dao/log"
	"LAPP_GAAS_GFrame_BACKEND/db"
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/jit"
	basmodel "LAPP_GAAS_GFrame_BACKEND/models/base"
	model "LAPP_GAAS_GFrame_BACKEND/models/jit"
	"LAPP_GAAS_GFrame_BACKEND/utils"
	"LAPP_GAAS_GFrame_BACKEND/web/models"
	"fmt"
	"github.com/tealeg/xlsx"
	"strconv"
	"time"
)

/******************************************************************************
 *
 * @Description              : ShipOrder的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 13:42:26
 *
 ******************************************************************************/
var DefaultConditionOfShipOrder = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ShipOrder_ShipOrderId.UrlParameterName:    grmi.NewConditionItem(meta.ShipOrder_ShipOrderId, grmi.Equal, true),
		meta.ShipOrder_Descr.UrlParameterName:          grmi.NewConditionItem(meta.ShipOrder_Descr, grmi.Equal, false),
		meta.ShipOrder_ShipTemplateId.UrlParameterName: grmi.NewConditionItem(meta.ShipOrder_ShipTemplateId, grmi.Equal, false),
		meta.ShipOrder_ProjectId.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_ProjectId, grmi.Equal, false),
		meta.ShipOrder_StartSequence.UrlParameterName:  grmi.NewConditionItem(meta.ShipOrder_StartSequence, grmi.Equal, false),
		meta.ShipOrder_EndSequence.UrlParameterName:    grmi.NewConditionItem(meta.ShipOrder_EndSequence, grmi.Equal, false),
		meta.ShipOrder_Status.UrlParameterName:         grmi.NewConditionItem(meta.ShipOrder_Status, grmi.Equal, false),
		meta.ShipOrder_ShipType.UrlParameterName:       grmi.NewConditionItem(meta.ShipOrder_ShipType, grmi.Equal, false),
		meta.ShipOrder_OrderInfo.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_OrderInfo, grmi.Equal, false),
		meta.ShipOrder_PrinterId.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_PrinterId, grmi.Equal, false),
		meta.ShipOrder_TemplateFile.UrlParameterName:   grmi.NewConditionItem(meta.ShipOrder_TemplateFile, grmi.Equal, false),
		meta.ShipOrder_PlanQty.UrlParameterName:        grmi.NewConditionItem(meta.ShipOrder_PlanQty, grmi.Equal, false),
		meta.ShipOrder_ActualQty.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_ActualQty, grmi.Equal, false),
		meta.ShipOrder_OpenTime.UrlParameterName:       grmi.NewConditionItem(meta.ShipOrder_OpenTime, grmi.Approximate, false),
		meta.ShipOrder_CloseTime.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_CloseTime, grmi.Approximate, false),
		meta.ShipOrder_Operator.UrlParameterName:       grmi.NewConditionItem(meta.ShipOrder_Operator, grmi.Equal, false),
		meta.ShipOrder_CtrlPara1.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_CtrlPara1, grmi.Equal, false),
		meta.ShipOrder_CtrlPara2.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_CtrlPara2, grmi.Equal, false),
		meta.ShipOrder_CtrlPara3.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_CtrlPara3, grmi.Equal, false),
		meta.ShipOrder_CtrlPara4.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_CtrlPara4, grmi.Equal, false),
		meta.ShipOrder_CtrlStr1.UrlParameterName:       grmi.NewConditionItem(meta.ShipOrder_CtrlStr1, grmi.Equal, false),
		meta.ShipOrder_CtrlStr2.UrlParameterName:       grmi.NewConditionItem(meta.ShipOrder_CtrlStr2, grmi.Equal, false),
		meta.ShipOrder_CtrlStr3.UrlParameterName:       grmi.NewConditionItem(meta.ShipOrder_CtrlStr3, grmi.Equal, false),
		meta.ShipOrder_CtrlStr4.UrlParameterName:       grmi.NewConditionItem(meta.ShipOrder_CtrlStr4, grmi.Equal, false),
		meta.ShipOrder_CtrlTime1.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_CtrlTime1, grmi.Approximate, false),
		meta.ShipOrder_CtrlTime2.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_CtrlTime2, grmi.Approximate, false),
		meta.ShipOrder_CtrlTime3.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_CtrlTime3, grmi.Approximate, false),
		meta.ShipOrder_CtrlTime4.UrlParameterName:      grmi.NewConditionItem(meta.ShipOrder_CtrlTime4, grmi.Approximate, false),
		meta.ShipOrder_LastModify.UrlParameterName:     grmi.NewConditionItem(meta.ShipOrder_LastModify, grmi.Approximate, false),
		meta.ShipOrder_LastUser.UrlParameterName:       grmi.NewConditionItem(meta.ShipOrder_LastUser, grmi.Equal, false),
		meta.ShipOrder_CreateTime.UrlParameterName:     grmi.NewConditionItem(meta.ShipOrder_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : ShipOrder的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 13:42:26
 *
 ******************************************************************************/
var DefaultConditionOfShipOrderAndPaging = grmi.NewCondition(
	DefaultConditionOfShipOrder.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : ShipOrderServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ShipOrder的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 13:42:26
 *
 ******************************************************************************/
type ShipOrderServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewShipOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ShipOrderDAOImplement实例
 *
 * @Return Value             : ShipOrderDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 13:42:26
 *
 ******************************************************************************/
func NewShipOrderServiceImplement() *ShipOrderServiceImplement {
	return &ShipOrderServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/jit/ShipOrderService.InsertOne
 *
 ******************************************************************************/
func (impl *ShipOrderServiceImplement) InsertOne(user *models.Usertab, entity *model.ShipOrder) error {

	grmi.Log(user, "/services/jit/implments/ShipOrder.service.impl.go", "InsertOneShipOrder", "插入一个ShipOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewShipOrderDAO(session, user.Pid, user.Userid)
	output, err := xlsx.FileToSlice("web/" + entity.TemplateFile)
	if err != nil {
		return fmt.Errorf("读取文件失败")
	}
	entity.Status = basmodel.SHIP_ORDER_STATUS_PADDING
	var shipOrderItemlst []model.ShipOrderItemlst
	var articleId []string
	if len(output) < 1 {
		return fmt.Errorf("文件格式错误")
	}
	for rowIndex, row := range output[0] {
		if len(row) < 12 {
			return fmt.Errorf("文件格式无法解析")
		}
		if rowIndex == 8 {
			entity.ShipOrderId = row[11]
			entity.ShipTemplateId = row[11]
			entity.Descr = row[11]
		}
		if rowIndex == 10 {
			deliver, _ := time.ParseInLocation("20060102", row[2], time.Local)
			entity.DeliverDate = grmi.Date(deliver)
			ship, _ := time.ParseInLocation("20060102", row[11], time.Local)
			entity.ShipDate = grmi.Date(ship)
		}
		if rowIndex == 12 {
			if i, err := strconv.ParseInt(row[0], 10, 64); err == nil {
				entity.StartSequence = int(i)
			}
		}
		if rowIndex >= 12 {
			if row[6] == "" {
				continue
			}
			planQty := 0
			orderQty := 0
			if i, err := strconv.ParseInt(row[7], 10, 64); err == nil {
				orderQty = int(i)
			}
			if i, err := strconv.ParseInt(row[8], 10, 64); err == nil {
				planQty = int(i)
			}
			info := model.ShipOrderItemlst{
				ShipOrderId:     entity.ShipOrderId,
				ItemId:          row[6],
				Descr:           row[2],
				PlanQty:         planQty,
				OrderQty:        orderQty,
				SupplierPartId:  row[6],
				CustomerPartId:  row[5],
				PartId:          row[6],
				PartName:        row[2],
				ShortShipToggle: false,
			}
			if i, err := strconv.ParseInt(row[0], 10, 64); err == nil {
				entity.EndSequence = int(i)
				info.Pos = int(i)
			}

			//判断是否是零件
			if orderQty == 0 && planQty > 0 {
				articleId = append(articleId, info.ItemId)
			} else {
				info.ItemType = "assembly"
			}
			shipOrderItemlst = append(shipOrderItemlst, info)

		}
	}
	//判断文件是否导入
	record, err := dao.SelectOne(entity.ShipOrderId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	//查询article是否存在
	articleDao := basedal.NewArticleDAO(session, user.Pid, user.Userid)
	articleList, err := articleDao.SelectWhere(articleId)
	articleMap := make(map[string]basmodel.Article)
	for _, v := range articleList {
		articleMap[v.ArtId] = v
	}
	allTal := 0
	for k, v := range shipOrderItemlst {
		shipOrderItemlst[k].Status = basmodel.SHIP_ORDER_STATUS_PADDING
		_, ok := articleMap[v.ItemId]
		if ok {
			shipOrderItemlst[k].ItemType = "inside"
			shipOrderItemlst[k].ShipValidateToggle = true
			allTal += v.PlanQty
		} else {
			if v.ItemType == "" {
				shipOrderItemlst[k].ItemType = "external"
			}
			shipOrderItemlst[k].ShipValidateToggle = false
		}
	}
	entity.PlanQty = allTal
	session.Begin()

	//插入明细表
	itemListDao := dal.NewShipOrderItemlstDAO(session, user.Pid, user.Userid)
	err = itemListDao.Insert(&shipOrderItemlst)
	if err != nil {
		session.Rollback()
		return err
	}
	err = dao.InsertOne(entity)
	if err != nil {
		session.Rollback()
		return err
	}
	session.Commit()
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/jit/ShipOrderService.DeleteOne
 *
 ******************************************************************************/
func (impl *ShipOrderServiceImplement) DeleteOne(user *models.Usertab, shipOrderId string) error {

	grmi.Log(user, "/services/jit/implments/ShipOrder.service.impl.go", "DeleteOneShipOrder", "删除一个ShipOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewShipOrderDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(shipOrderId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	//判断状态是否可以取消
	if record.Status != basmodel.SHIP_ORDER_STATUS_PADDING {
		return grmi.NewBusinessError("计划一开始无法删除!")
	}
	itemDao := dal.NewShipOrderItemlstDAO(session, user.Pid, user.Userid)
	session.Begin()
	urlParameters := make(map[string]string)
	urlParameters["JIT_ShipOrderItemlst-ShipOrderId"] = record.ShipOrderId
	condition := DefaultConditionOfShipOrderItemlstAndPaging
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.NewBusinessError("系统异常!")
	}
	err = itemDao.DeleteWhere(predicates)
	if err != nil {
		session.Rollback()
		return err
	}
	err = dao.DeleteOne(shipOrderId)
	if err != nil {
		session.Rollback()
		return err
	}
	session.Commit()
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/jit/ShipOrderService.SelectOne
 *
 ******************************************************************************/
func (impl *ShipOrderServiceImplement) SelectOne(user *models.Usertab, shipOrderId string) (*model.ShipOrder, error) {

	grmi.Log(user, "/services/jit/implments/ShipOrder.service.impl.go", "SelectOneShipOrder", "查询一个ShipOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewShipOrderDAO(session, user.Pid, user.Userid)
	listdao := dal.NewShipOrderItemlstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(shipOrderId)
	if err != nil {
		return nil, err
	}
	items, err := listdao.Select([]grmi.Predicate{
		meta.ShipOrderItemlst_ShipOrderId.NewPredicate(grmi.Equal, shipOrderId),
		meta.ShipOrderItemlst_ShipValidateToggle.NewPredicate(grmi.Equal, 1),
	}, nil)
	if err != nil {
		return nil, err
	}
	result.ShipOrderItemlst = items
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/jit/ShipOrderService.UpdateOne
 *
 ******************************************************************************/
func (impl *ShipOrderServiceImplement) UpdateOne(user *models.Usertab, entity *model.ShipOrder) error {

	grmi.Log(user, "/services/jit/implments/ShipOrder.service.impl.go", "UpdateOneShipOrder", "修改一个ShipOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewShipOrderDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.ShipOrderId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/jit/ShipOrderService.Insert
 *
 ******************************************************************************/
func (impl *ShipOrderServiceImplement) Insert(user *models.Usertab, entities *[]model.ShipOrder) error {

	grmi.Log(user, "/services/jit/implments/ShipOrder.service.impl.go", "InsertShipOrder", "插入多个ShipOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewShipOrderDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ShipOrderId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/jit/ShipOrderService.Delete
 *
 ******************************************************************************/
func (impl *ShipOrderServiceImplement) Delete(user *models.Usertab, entities *[]model.ShipOrder) error {

	grmi.Log(user, "/services/jit/implments/ShipOrder.service.impl.go", "DeleteShipOrder", "删除多个ShipOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewShipOrderDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ShipOrderId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/jit/ShipOrderService.Select
 *
 ******************************************************************************/
func (impl *ShipOrderServiceImplement) Select(user *models.Usertab, urlParameters map[string]string) ([]model.ShipOrder, error) {

	grmi.Log(user, "/services/jit/implments/ShipOrder.service.impl.go", "SelectShipOrder", "查询ShipOrder")

	condition := DefaultConditionOfShipOrderAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewShipOrderDAO(session, user.Pid, user.Userid)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/jit/ShipOrderService.SelectList
 *
 ******************************************************************************/
func (impl *ShipOrderServiceImplement) SelectList(user *models.Usertab, deliverDate string) ([]model.ShipOrder, error) {

	grmi.Log(user, "/services/jit/implments/ShipOrder.SelectList.impl.go", "SelectShipOrder", "查询ShipOrder")

	condition := DefaultConditionOfShipOrderAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	var predicates []grmi.Predicate
	if !utils.ValueIsEmpty(deliverDate){
		predicates = []grmi.Predicate{
			meta.ShipOrder_DeliverDate.NewPredicate(grmi.Equal, deliverDate),
			meta.ShipOrder_Status.NewPredicate(grmi.NotEqual, basmodel.WO_STATUS_FINISHED),
		}
	}else{
		predicates = []grmi.Predicate{
			meta.ShipOrder_Status.NewPredicate(grmi.NotEqual, basmodel.WO_STATUS_FINISHED),
		}
	}
	predicates = append(predicates,)
	dao := dal.NewShipOrderDAO(session, user.Pid, user.Userid)
	result, err := dao.Select(predicates, condition.OrderByFields)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/jit/ShipOrderService.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ShipOrderServiceImplement) SelectAndPaging(user *models.Usertab, urlParameters map[string]string) (grmi.PagingResult, error) {

	grmi.Log(user, "/services/jit/implments/ShipOrder.service.impl.go", "SelectShipOrder", "查询ShipOrder")

	condition := DefaultConditionOfShipOrderAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	dao := dal.NewShipOrderDAO(session, user.Pid, user.Userid)
	condition.Fill(urlParameters)
	result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/jit/ShipOrderService.Update
 *
 ******************************************************************************/
func (impl *ShipOrderServiceImplement) Update(user *models.Usertab, entities *[]model.ShipOrder) error {

	grmi.Log(user, "/services/jit/implments/ShipOrder.service.impl.go", "UpdateShipOrder", "修改多个ShipOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewShipOrderDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.ShipOrderId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/jit/ShipOrderService.ScanCarPackOrders
 *
 ******************************************************************************/
func (impl *ShipOrderServiceImplement) ScanCarPackOrders(user *models.Usertab, shipOrderId string, packOrderId string) (bool,string, error) {

	grmi.Log(user, "/services/jit/implments/ShipOrder.service.impl.go", "ScanCarPackOrders", "扫描ShipOrder")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()

	IsClose := "doing"
	// add Begin() before any action
	if err := session.Begin(); err != nil {
		return false,IsClose, err
	}
	packDao := logDal.NewPackOrderDAO(session, user.Pid, user.Userid)
	dao := dal.NewShipOrderDAO(session, user.Pid, user.Userid)
	lstDao := dal.NewShipOrderItemlstDAO(session, user.Pid, user.Userid)
	dataDao := dal.NewShipOrderDatalstDAO(session, user.Pid, user.Userid)

	//第一步:查询包装单信息
	shipInfo, err := dao.SelectOne(shipOrderId)
	if err != nil {
		session.Rollback()
		return false,IsClose, err
	}
	if shipInfo == nil {
		session.Rollback()
		return true,IsClose, grmi.NewBusinessError("发运单信息不存在!")
	}
	packInfo, err := packDao.SelectOne(packOrderId)
	if err != nil {
		session.Rollback()
		return false,IsClose, err
	}
	if packInfo == nil {
		session.Rollback()
		return true,IsClose, grmi.NewBusinessError("包装单信息不存在!")
	}
	if packInfo.Status != basmodel.WO_STATUS_FINISHED{
		session.Rollback()
		return true,IsClose, grmi.NewBusinessError("包装单状态未完成!")
	}
	//第二步:根据包装单信心，查询对应的发运单项信息
	itemInfo, err := lstDao.SelectOne(shipOrderId, packInfo.MaterialId)
	if err != nil {
		session.Rollback()
		return false,IsClose, err
	}
	if itemInfo == nil {
		session.Rollback()
		return true,IsClose, grmi.NewBusinessError("发运项信息不存在!")
	}
	//判断是否扫描过
	packDatalist, err := dataDao.Select([]grmi.Predicate{
		meta.ShipOrderDatalst_ShipObjId.NewPredicate(grmi.Equal, packOrderId),
	}, nil)
	if err != nil {
		session.Rollback()
		return false,IsClose, err
	}
	if len(packDatalist) > 0 {
		session.Rollback()
		return true,IsClose, grmi.NewBusinessError("该包装单已经扫描过!")
	}
	//第三步:逻辑判断是否符合规则
	actQty := utils.ValueToInt(packInfo.ActQty, 0)
	//1）判断要货信息零件数，和包装单零件比较
	if itemInfo.PlanQty > (itemInfo.ActualQty + actQty) {
		//满足进包装条件,并且更新shiporder的零件数量
		itemInfo.ActualQty = (itemInfo.ActualQty + actQty)
		itemInfo.Status = basmodel.SHIP_ORDER_STATUS_RUNNING
		err = lstDao.UpdateOne(itemInfo)
		if err != nil {
			session.Rollback()
			return false,IsClose, err
		}

		//查询最后一条的pos
		posInfo, err := dataDao.SelectLastPos(shipOrderId)
		if err != nil {
			session.Rollback()
			return false,IsClose, err
		}
		var pos int
		if posInfo == nil {
			pos = 1
		} else {
			pos = (posInfo.Pos + 1)
		}
		//插入包装明细
		datalst := new(model.ShipOrderDatalst)
		datalst.PlantNr = user.Pid
		datalst.Pos = pos
		datalst.ItemId = packInfo.MaterialId
		datalst.Status = basmodel.SHIP_ORDER_STATUS_SUCCESS
		datalst.ActualQty = utils.ValueToInt(packInfo.ActQty, 0)
		datalst.PlanQty = utils.ValueToInt(packInfo.PlanQty, 0)
		datalst.ShipOrderId = shipOrderId
		datalst.ShipObjId = packOrderId
		err = dataDao.InsertOne(datalst)
		if err != nil {
			session.Rollback()
			return false,IsClose, err
		}
		shipInfo.ActualQty = (shipInfo.ActualQty + actQty)
		shipInfo.Status = basmodel.SHIP_ORDER_STATUS_RUNNING
		err = dao.UpdateOne(shipInfo)
		if err != nil {
			session.Rollback()
			return false,IsClose, err
		}
	} else if itemInfo.PlanQty == (itemInfo.ActualQty + actQty) {
		//满足关闭该项条件
		itemInfo.ActualQty = (itemInfo.ActualQty + actQty)
		itemInfo.Status = basmodel.SHIP_ORDER_STATUS_SUCCESS
		err = lstDao.UpdateOne(itemInfo)
		if err != nil {
			session.Rollback()
			return false,IsClose, err
		}

		//查询最后一条的pos
		posInfo, err := dataDao.SelectLastPos(shipOrderId)
		if err != nil {
			session.Rollback()
			return false,IsClose, err
		}
		var pos int
		if posInfo == nil {
			pos = 1
		} else {
			pos = (posInfo.Pos + 1)
		}
		//插入包装明细
		datalst := new(model.ShipOrderDatalst)
		datalst.PlantNr = user.Pid
		datalst.Pos = pos
		datalst.ItemId = packInfo.MaterialId
		datalst.Status = basmodel.SHIP_ORDER_STATUS_SUCCESS
		datalst.ActualQty = utils.ValueToInt(packInfo.ActQty, 0)
		datalst.PlanQty = utils.ValueToInt(packInfo.PlanQty, 0)
		datalst.ShipOrderId = shipOrderId
		datalst.ShipObjId = packOrderId
		err = dataDao.InsertOne(datalst)
		if err != nil {
			session.Rollback()
			return false,IsClose, err
		}
		//判断是否已经全部扫描完毕,如果全部完毕，那么可以关闭发运单
		items, err := lstDao.Select([]grmi.Predicate{
			meta.ShipOrderItemlst_ShipOrderId.NewPredicate(grmi.Equal, shipOrderId),
			meta.ShipOrderItemlst_ShipValidateToggle.NewPredicate(grmi.Equal, 1),
			meta.ShipOrderItemlst_Status.NewPredicate(grmi.LessThen, basmodel.SHIP_ORDER_STATUS_SUCCESS),
		}, nil)
		if len(items) == 0 {
			shipInfo.ActualQty = (shipInfo.ActualQty + actQty)
			shipInfo.Status = basmodel.SHIP_ORDER_STATUS_SUCCESS
			err = dao.UpdateOne(shipInfo)
			if err != nil {
				session.Rollback()
				return false,"doing", err
			}
			IsClose = "success"
		} else {
			shipInfo.ActualQty = (shipInfo.ActualQty + actQty)
			shipInfo.Status = basmodel.SHIP_ORDER_STATUS_RUNNING
			err = dao.UpdateOne(shipInfo)
			if err != nil {
				session.Rollback()
				return false,IsClose, err
			}
		}
	} else {
		session.Rollback()
		return true,IsClose, grmi.NewBusinessError("该包装单零件数量大于需求零件!")
	}
	session.Commit()
	return true,IsClose, nil
}
