// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	baseDal "LAPP_GAAS_GFrame_BACKEND/dao/base"
	omDal "LAPP_GAAS_GFrame_BACKEND/dao/om"
	dal "LAPP_GAAS_GFrame_BACKEND/dao/qm"
	"LAPP_GAAS_GFrame_BACKEND/db"
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	bmeta "LAPP_GAAS_GFrame_BACKEND/meta/base"
	meta "LAPP_GAAS_GFrame_BACKEND/meta/qm"
	bmodel "LAPP_GAAS_GFrame_BACKEND/models/base"
	model "LAPP_GAAS_GFrame_BACKEND/models/qm"
	"LAPP_GAAS_GFrame_BACKEND/utils"
	"LAPP_GAAS_GFrame_BACKEND/web/models"
	"fmt"
)

/******************************************************************************
 *
 * @Description              : ReclinerReclst的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
var DefaultConditionOfReclinerReclst = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.ReclinerReclst_RecNr.UrlParameterName:         grmi.NewConditionItem(meta.ReclinerReclst_RecNr, grmi.Equal, true),
		meta.ReclinerReclst_RecType.UrlParameterName:       grmi.NewConditionItem(meta.ReclinerReclst_RecType, grmi.Equal, true),
		meta.ReclinerReclst_Line.UrlParameterName:          grmi.NewConditionItem(meta.ReclinerReclst_Line, grmi.Equal, true),
		meta.ReclinerReclst_ArtId.UrlParameterName:         grmi.NewConditionItem(meta.ReclinerReclst_ArtId, grmi.Equal, false),
		meta.ReclinerReclst_SerialOrderId.UrlParameterName: grmi.NewConditionItem(meta.ReclinerReclst_SerialOrderId, grmi.Equal, false),
		meta.ReclinerReclst_ReclinerNr.UrlParameterName:    grmi.NewConditionItem(meta.ReclinerReclst_ReclinerNr, grmi.Equal, false),
		meta.ReclinerReclst_ItemPartNr.UrlParameterName:    grmi.NewConditionItem(meta.ReclinerReclst_ItemPartNr, grmi.Equal, false),
		meta.ReclinerReclst_Status.UrlParameterName:        grmi.NewConditionItem(meta.ReclinerReclst_Status, grmi.Equal, false),
		meta.ReclinerReclst_LastModify.UrlParameterName:    grmi.NewConditionItem(meta.ReclinerReclst_LastModify, grmi.Approximate, false),
		meta.ReclinerReclst_LastUser.UrlParameterName:      grmi.NewConditionItem(meta.ReclinerReclst_LastUser, grmi.Equal, false),
		meta.ReclinerReclst_CreateTime.UrlParameterName:    grmi.NewConditionItem(meta.ReclinerReclst_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : ReclinerReclst的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
var DefaultConditionOfReclinerReclstAndPaging = grmi.NewCondition(
	DefaultConditionOfReclinerReclst.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : ReclinerReclstServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ReclinerReclst的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
type ReclinerReclstServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewReclinerReclstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ReclinerReclstDAOImplement实例
 *
 * @Return Value             : ReclinerReclstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func NewReclinerReclstServiceImplement() *ReclinerReclstServiceImplement {
	return &ReclinerReclstServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/qm/ReclinerReclstService.InsertOne
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) InsertOne(user *models.Usertab, entity *model.ReclinerReclst) error {

	grmi.Log(user, "/services/qm/implments/ReclinerReclst.service.impl.go", "InsertOneReclinerReclst", "插入一个ReclinerReclst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReclinerReclstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.RecNr)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	seriDao := omDal.NewSerialOrderDAO(session, user.Pid, user.Userid)
	seriInfo, err := seriDao.SelectBySerialOrder(entity.SerialOrderId)
	if err != nil {
		return err
	}
	if seriInfo == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	//查询物料主数据表
	artDao := baseDal.NewArticleDAO(session, user.Pid, user.Userid)
	artInfo, err := artDao.SelectOne(seriInfo.ArtId)
	if err != nil {
		return err
	}
	if artInfo == nil {
		return grmi.NewBusinessError("客户订单号没有维护!")
	}
	orderId := entity.SerialOrderId

	entity.ArtId = seriInfo.ArtId
	entity.RecType = model.QM_REC_TYPE
	entity.Status = "N"
	if len(orderId) < 27 {
		return grmi.NewBusinessError("序列订单长度错误!")
	}
	entity.ReclinerNr = orderId[0:19] + "R" + orderId[20:27]
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/qm/ReclinerReclstService.InsertSeriOne
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) InsertSeriOne(user *models.Usertab, entity *model.ReclinerReclst) error {

	grmi.Log(user, "/services/qm/implments/ReclinerReclst.service.impl.go", "InsertOneReclinerReclst", "插入一个ReclinerReclst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReclinerReclstDAO(session, user.Pid, user.Userid)
	seriDao := omDal.NewSerialOrderDAO(session, user.Pid, user.Userid)
	seriInfo, err := seriDao.SelectBySerialOrder(entity.SerialOrderId)
	if err != nil {
		return err
	}
	if seriInfo == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	if seriInfo.PlanResourceId != "G-Frame Assy" {
		return grmi.NewBusinessError("该产线不是装配线!")
	}
	//查询物料主数据表
	artDao := baseDal.NewArticleDAO(session, user.Pid, user.Userid)
	artInfo, err := artDao.SelectOne(seriInfo.ArtId)
	if err != nil {
		return err
	}
	if artInfo == nil {
		return grmi.NewBusinessError("客户订单号没有维护!")
	}
	entity.ArtId = seriInfo.ArtId
	entity.Line = seriInfo.PlanResourceId
	entity.RecType = model.QM_SERI_TYPE
	entity.Status = "N"
	orderId := entity.SerialOrderId
	if len(orderId) < 27 {
		return grmi.NewBusinessError("序列订单长度错误!")
	}
	entity.ReclinerNr = orderId[0:19] + "R" + orderId[20:27]
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/qm/ReclinerReclstService.SelectSeriOne
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) SelectSeriOne(user *models.Usertab, orderId string) (*model.ReclinerReclst, error) {

	grmi.Log(user, "/services/qm/implments/ReclinerReclst.service.impl.go", "InsertOneReclinerReclst", "插入一个ReclinerReclst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	seriDao := omDal.NewSerialOrderDAO(session, user.Pid, user.Userid)
	seriInfo, err := seriDao.SelectBySerialOrder(orderId)
	if err != nil {
		return nil, err
	}
	if seriInfo == nil {
		return nil, grmi.NewBusinessError("不存在指定记录!")
	}
	if seriInfo.PlanResourceId != "G-Frame Assy" {
		return nil, grmi.NewBusinessError("该产线不是装配线!")
	}
	//查询物料主数据表
	artDao := baseDal.NewArticleDAO(session, user.Pid, user.Userid)
	artInfo, err := artDao.SelectOne(seriInfo.ArtId)
	if err != nil {
		return nil, err
	}
	if artInfo == nil {
		return nil, grmi.NewBusinessError("客户订单号没有维护!")
	}
	entity := new(model.ReclinerReclst)

	entity.PlantNr = user.Pid
	entity.ArtId = seriInfo.ArtId
	entity.SerialOrderId = orderId
	entity.Line = seriInfo.PlanResourceId
	entity.RecType = model.QM_SERI_TYPE
	if len(orderId) < 27 {
		return nil, grmi.NewBusinessError("序列订单长度错误!")
	}
	entity.ReclinerNr = orderId[0:19] + "R" + orderId[20:27]
	return entity, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/qm/ReclinerReclstService.AddPrinterInfo
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) AddPrinterInfo(user *models.Usertab, entity *model.ReclinerReclst) error {

	grmi.Log(user, "/services/qm/implments/ReclinerReclst.service.impl.go", "InsertOneReclinerReclst", "插入一个ReclinerReclst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()

	templateId := "TSC-BARCODE"
	dao := baseDal.NewLabelTemplateHeadDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(templateId)
	if err != nil {
		return err
	}
	lstdao := baseDal.NewLabelTemplateDetailDAO(session, user.Pid, user.Userid)
	list, err := lstdao.Select([]grmi.Predicate{
		bmeta.LabelTemplateDetail_LabelTemplateId.NewPredicate(grmi.Equal, templateId),
	}, nil)
	if err != nil {
		return err
	}
	result.LabelTemplateDetail = list

	//查询物料主数据表
	artDao := baseDal.NewArticleDAO(session, user.Pid, user.Userid)
	artInfo, err := artDao.SelectOne(entity.ArtId)
	if err != nil {
		return err
	}
	if artInfo == nil {
		return grmi.NewBusinessError("客户订单号没有维护!")
	}
	//查询序列订单表
	orderDao := omDal.NewSerialOrderDAO(session, user.Pid, user.Userid)
	orderInfo, err := orderDao.SelectBySerialOrder(entity.SerialOrderId)
	if err != nil {
		return err
	}
	if orderInfo == nil {
		return grmi.NewBusinessError("序列订单订单不存在!")
	}
	snr := new(models.Snrtab)
	snr.Finr = bmodel.PlantNr
	snr.Snrid = "PrintId"
	headId, err := snr.GetNextSnr("PrintId")
	if err != nil {
		fmt.Println(err)
		return grmi.NewBusinessError("打印头部生成错误!")
	}

	// add Begin() before any action
	if err := session.Begin(); err != nil {
		return err
	}
	headDao := baseDal.NewLabelHeadDAO(session, user.Pid, user.Userid)
	head := new(bmodel.LabelHead)
	head.PlantNr = result.PlantNr
	head.LabelId = headId
	head.Status = 0
	head.LabelTemplateId = result.LabelTemplateId
	head.PrinterId = result.PrinterId
	head.PrintQty = 1
	head.BusinessObjType = "BACK"
	head.BusinessObjId = entity.SerialOrderId
	err = headDao.InsertOne(head)
	if err != nil {
		session.Rollback()
		return err
	}

	detailDao := baseDal.NewLabelDetailDAO(session, user.Pid, user.Userid)
	for k, v := range list {
		detail := new(bmodel.LabelDetail)
		head.PlantNr = result.PlantNr
		detail.LabelId = headId
		detail.Pos = (k + 1)
		detail.VariableName = v.LabelItemValue
		//映射值
		if detail.VariableName == "$SN$" {
			detail.VariableValue = entity.ReclinerNr
		} else if detail.VariableName == "$DATE$" {
			dateStr := utils.TimeFormat(orderInfo.PlanStartTime.Restore(), "yyyy/MM/dd")
			detail.VariableValue = dateStr
		} else if detail.VariableName == "$CUSTID$" {
			detail.VariableValue = artInfo.AlternativeArtId
		} else if detail.VariableName == "$ORDERID$" {
			detail.VariableValue = entity.ReclinerNr
		}
		err = detailDao.InsertOne(detail)
		if err != nil {
			session.Rollback()
			return err
		}
	}
	session.Commit()
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/qm/ReclinerReclstService.CreatePackOrderPrintInfo
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) CreateRecPrintInfo(entity model.ReclinerReclst) error {

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()

	templateId := "TSC-BARCODE"
	dao := baseDal.NewLabelTemplateHeadDAO(session, bmodel.PlantNr, "Rec")
	result, err := dao.SelectOne(templateId)
	if err != nil {
		return err
	}
	lstdao := baseDal.NewLabelTemplateDetailDAO(session, bmodel.PlantNr, "Rec")
	list, err := lstdao.Select([]grmi.Predicate{
		bmeta.LabelTemplateDetail_LabelTemplateId.NewPredicate(grmi.Equal, templateId),
	}, nil)
	if err != nil {
		return err
	}
	result.LabelTemplateDetail = list

	//查询物料主数据表
	artDao := baseDal.NewArticleDAO(session, bmodel.PlantNr, "Rec")
	artInfo, err := artDao.SelectOne(entity.ArtId)
	if err != nil {
		return err
	}
	if artInfo == nil {
		return grmi.NewBusinessError("客户订单号没有维护!")
	}
	//查询序列订单表
	orderDao := omDal.NewSerialOrderDAO(session, bmodel.PlantNr, "Rec")
	orderInfo, err := orderDao.SelectBySerialOrder(entity.SerialOrderId)
	if err != nil {
		return err
	}
	if orderInfo == nil {
		return grmi.NewBusinessError("序列订单订单不存在!")
	}
	snr := new(models.Snrtab)
	snr.Finr = bmodel.PlantNr
	snr.Snrid = "PrintId"
	headId, err := snr.GetNextSnr("PrintId")
	if err != nil {
		fmt.Println(err)
		return grmi.NewBusinessError("打印头部生成错误!")
	}

	// add Begin() before any action
	if err := session.Begin(); err != nil {
		return err
	}
	headDao := baseDal.NewLabelHeadDAO(session, bmodel.PlantNr, "Rec")
	head := new(bmodel.LabelHead)
	head.PlantNr = result.PlantNr
	head.LabelId = headId
	head.Status = 0
	head.LabelTemplateId = result.LabelTemplateId
	head.PrinterId = result.PrinterId
	head.PrintQty = 1
	head.BusinessObjType = "BACK"
	head.BusinessObjId = entity.SerialOrderId
	err = headDao.InsertOne(head)
	if err != nil {
		session.Rollback()
		return err
	}

	detailDao := baseDal.NewLabelDetailDAO(session, bmodel.PlantNr, "Rec")
	for k, v := range list {
		detail := new(bmodel.LabelDetail)
		head.PlantNr = result.PlantNr
		detail.LabelId = headId
		detail.Pos = (k + 1)
		detail.VariableName = v.LabelItemValue
		//映射值
		if detail.VariableName == "$SN$" {
			detail.VariableValue = entity.ReclinerNr
		} else if detail.VariableName == "$DATE$" {
			dateStr := utils.TimeFormat(orderInfo.PlanStartTime.Restore(), "yyyy/MM/dd")
			detail.VariableValue = dateStr
		} else if detail.VariableName == "$CUSTID$" {
			detail.VariableValue = artInfo.AlternativeArtId
		} else if detail.VariableName == "$ORDERID$" {
			detail.VariableValue = entity.ReclinerNr
		}
		err = detailDao.InsertOne(detail)
		if err != nil {
			session.Rollback()
			return err
		}
	}
	session.Commit()
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/qm/ReclinerReclstService.DeleteOne
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) DeleteOne(user *models.Usertab, recNr int) error {

	grmi.Log(user, "/services/qm/implments/ReclinerReclst.service.impl.go", "DeleteOneReclinerReclst", "删除一个ReclinerReclst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReclinerReclstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(recNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(recNr)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/qm/ReclinerReclstService.SelectOne
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) SelectOne(user *models.Usertab, recNr int) (*model.ReclinerReclst, error) {

	grmi.Log(user, "/services/qm/implments/ReclinerReclst.service.impl.go", "SelectOneReclinerReclst", "查询一个ReclinerReclst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReclinerReclstDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(recNr)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/qm/ReclinerReclstService.UpdateOne
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) UpdateOne(user *models.Usertab, entity *model.ReclinerReclst) error {

	grmi.Log(user, "/services/qm/implments/ReclinerReclst.service.impl.go", "UpdateOneReclinerReclst", "修改一个ReclinerReclst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReclinerReclstDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.RecNr)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/qm/ReclinerReclstService.Insert
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) Insert(user *models.Usertab, entities *[]model.ReclinerReclst) error {

	grmi.Log(user, "/services/qm/implments/ReclinerReclst.service.impl.go", "InsertReclinerReclst", "插入多个ReclinerReclst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReclinerReclstDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.RecNr)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/qm/ReclinerReclstService.Delete
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) Delete(user *models.Usertab, entities *[]model.ReclinerReclst) error {

	grmi.Log(user, "/services/qm/implments/ReclinerReclst.service.impl.go", "DeleteReclinerReclst", "删除多个ReclinerReclst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReclinerReclstDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.RecNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/qm/ReclinerReclstService.Select
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) Select(user *models.Usertab, urlParameters map[string]string) (interface{}, error) {

	grmi.Log(user, "/services/qm/implments/ReclinerReclst.service.impl.go", "SelectReclinerReclst", "查询ReclinerReclst")

	condition := DefaultConditionOfReclinerReclstAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewReclinerReclstDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/qm/ReclinerReclstService.Update
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) Update(user *models.Usertab, entities *[]model.ReclinerReclst) error {

	grmi.Log(user, "/services/qm/implments/ReclinerReclst.service.impl.go", "UpdateReclinerReclst", "修改多个ReclinerReclst")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReclinerReclstDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.RecNr)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/log/PackOrderService.SelectUnPrint
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) SelectUnPrint(num int) ([]model.ReclinerReclst, error) {
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReclinerReclstDAO(session, bmodel.PlantNr, "Rec")
	if num < 1 {
		num = 50
	}
	result, err := dao.SelectUnPrint(num)
	if err != nil {
		return nil, err
	}
	return result, nil

}

/******************************************************************************
 *
 * @Reference LAPP_GAAS_GFrame_BACKEND/services/log/PackOrderService.UpdateUnPrint
 *
 ******************************************************************************/
func (impl *ReclinerReclstServiceImplement) UpdateUnPrint(recIds []int) error {
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewReclinerReclstDAO(session, bmodel.PlantNr, "Rec")
	err := dao.UpdateUnPrint(recIds)
	if err != nil {
		return err
	}
	return nil
}
