// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_GAAS_GFrame_BACKEND/models/base"
	"LAPP_GAAS_GFrame_BACKEND/web/middleware/jwts"
	"LAPP_GAAS_GFrame_BACKEND/web/models"
	"LAPP_GAAS_GFrame_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneReceiptHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ReceiptHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 11:26:18
 *
 ******************************************************************************/
func RegisterOneReceiptHead(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ReceiptHead) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ReceiptHead)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfReceiptHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ReceiptHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 11:26:18
 *
 ******************************************************************************/
func RegisterIDOfReceiptHead(party router.Party, httpMethod string, path string, method func(*models.Usertab, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		receiptHeadId := ctx.Params().GetString("receiptHeadId")

		err = method(user, receiptHeadId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneReceiptHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ReceiptHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 11:26:18
 *
 ******************************************************************************/
func RegisterInsertOneReceiptHead(party router.Party, path string, method func(*models.Usertab, *model.ReceiptHead) error) {

	RegisterOneReceiptHead(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneReceiptHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ReceiptHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 11:26:18
 *
 ******************************************************************************/
func RegisterDeleteOneReceiptHead(party router.Party, path string, method func(*models.Usertab, string) error) {

	RegisterIDOfReceiptHead(party, "DELETE", path+"/{receiptHeadId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneReceiptHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ReceiptHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 11:26:18
 *
 ******************************************************************************/
func RegisterSelectOneReceiptHead(party router.Party, path string, method func(*models.Usertab, string) (*model.ReceiptHead, error)) {

	party.Get(path+"/{receiptHeadId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		receiptHeadId := ctx.Params().GetString("receiptHeadId")
		result, err := method(user, receiptHeadId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneReceiptHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ReceiptHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 11:26:18
 *
 ******************************************************************************/
func RegisterUpdateOneReceiptHead(party router.Party, path string, method func(*models.Usertab, *model.ReceiptHead) error) {

	RegisterOneReceiptHead(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiReceiptHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ReceiptHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 11:26:18
 *
 ******************************************************************************/
func RegisterMultiReceiptHead(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ReceiptHead) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ReceiptHead, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertReceiptHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ReceiptHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 11:26:18
 *
 ******************************************************************************/
func RegisterInsertReceiptHead(party router.Party, path string, method func(*models.Usertab, *[]model.ReceiptHead) error) {

	RegisterMultiReceiptHead(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteReceiptHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ReceiptHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 11:26:18
 *
 ******************************************************************************/
func RegisterDeleteReceiptHead(party router.Party, path string, method func(*models.Usertab, *[]model.ReceiptHead) error) {

	RegisterMultiReceiptHead(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectReceiptHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ReceiptHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 11:26:18
 *
 ******************************************************************************/
func RegisterSelectReceiptHead(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateReceiptHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ReceiptHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 11:26:18
 *
 ******************************************************************************/
func RegisterUpdateReceiptHead(party router.Party, path string, method func(*models.Usertab, *[]model.ReceiptHead) error) {

	RegisterMultiReceiptHead(party, "PUT", path, method)
}
