// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package jit

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	model "LAPP_GAAS_GFrame_BACKEND/models/jit"
	"LAPP_GAAS_GFrame_BACKEND/web/middleware/jwts"
	"LAPP_GAAS_GFrame_BACKEND/web/models"
	"LAPP_GAAS_GFrame_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterOneShipOrder(party router.Party, httpMethod, path string, method func(*models.Usertab, *model.ShipOrder) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ShipOrder)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterIDOfShipOrder(party router.Party, httpMethod string, path string, method func(*models.Usertab, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		shipOrderId := ctx.Params().GetString("shipOrderId")

		err = method(user, shipOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterInsertOneShipOrder(party router.Party, path string, method func(*models.Usertab, *model.ShipOrder) error) {

	RegisterOneShipOrder(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterDeleteOneShipOrder(party router.Party, path string, method func(*models.Usertab, string) error) {

	RegisterIDOfShipOrder(party, "DELETE", path+"/{shipOrderId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterSelectOneShipOrder(party router.Party, path string, method func(*models.Usertab, string) (*model.ShipOrder, error)) {

	party.Get(path+"/{shipOrderId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		shipOrderId := ctx.Params().GetString("shipOrderId")
		result, err := method(user, shipOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterUpdateOneShipOrder(party router.Party, path string, method func(*models.Usertab, *model.ShipOrder) error) {

	RegisterOneShipOrder(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterMultiShipOrder(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ShipOrder) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ShipOrder, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterInsertShipOrder(party router.Party, path string, method func(*models.Usertab, *[]model.ShipOrder) error) {

	RegisterMultiShipOrder(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterDeleteShipOrder(party router.Party, path string, method func(*models.Usertab, *[]model.ShipOrder) error) {

	RegisterMultiShipOrder(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterSelectShipOrder(party router.Party, path string, method func(*models.Usertab, string) ([]model.ShipOrder, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		deliverDate := ctx.URLParam("deliverDate")
		result, err := method(user, deliverDate)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipOrder并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterQueryShipOrder(party router.Party, path string, method func(*models.Usertab, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateShipOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterUpdateShipOrder(party router.Party, path string, method func(*models.Usertab, *[]model.ShipOrder) error) {

	RegisterMultiShipOrder(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterScanCarPackOrders
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ShipOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterScanCarPackOrders(party router.Party, path string, method func(*models.Usertab, string, string) (bool, string, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		shipOrderId := ctx.URLParam("shipOrderId")
		packOrderId := ctx.URLParam("packOrderId")
		ok, isClose, err := method(user, shipOrderId, packOrderId)
		if err != nil && !ok {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), isClose)
			return
		}
		if err != nil && ok {
			supports.Error(ctx, iris.StatusAccepted, err.Error(), isClose)
			return
		}
		supports.Ok(ctx, "请扫描下一个待发运零件!", isClose)
	})
}
