// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package jit

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	model "LAPP_GAAS_GFrame_BACKEND/models/jit"
	"LAPP_GAAS_GFrame_BACKEND/web/middleware/jwts"
	"LAPP_GAAS_GFrame_BACKEND/web/models"
	"LAPP_GAAS_GFrame_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneShipOrderDatalst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ShipOrderDatalst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterOneShipOrderDatalst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ShipOrderDatalst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ShipOrderDatalst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfShipOrderDatalst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ShipOrderDatalst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterIDOfShipOrderDatalst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		shipOrderId := ctx.Params().GetString("shipOrderId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, shipOrderId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneShipOrderDatalst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ShipOrderDatalst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterInsertOneShipOrderDatalst(party router.Party, path string, method func(*models.Usertab, *model.ShipOrderDatalst) error) {

	RegisterOneShipOrderDatalst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneShipOrderDatalst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ShipOrderDatalst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterDeleteOneShipOrderDatalst(party router.Party, path string, method func(*models.Usertab, string, int) error) {

	RegisterIDOfShipOrderDatalst(party, "DELETE", path+"/{shipOrderId:string}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneShipOrderDatalst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ShipOrderDatalst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterSelectOneShipOrderDatalst(party router.Party, path string, method func(*models.Usertab, string, int) (*model.ShipOrderDatalst, error)) {

	party.Get(path+"/{shipOrderId:string}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		shipOrderId := ctx.Params().GetString("shipOrderId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, shipOrderId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneShipOrderDatalst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ShipOrderDatalst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterUpdateOneShipOrderDatalst(party router.Party, path string, method func(*models.Usertab, *model.ShipOrderDatalst) error) {

	RegisterOneShipOrderDatalst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiShipOrderDatalst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ShipOrderDatalst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterMultiShipOrderDatalst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ShipOrderDatalst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ShipOrderDatalst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertShipOrderDatalst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ShipOrderDatalst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterInsertShipOrderDatalst(party router.Party, path string, method func(*models.Usertab, *[]model.ShipOrderDatalst) error) {

	RegisterMultiShipOrderDatalst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteShipOrderDatalst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ShipOrderDatalst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterDeleteShipOrderDatalst(party router.Party, path string, method func(*models.Usertab, *[]model.ShipOrderDatalst) error) {

	RegisterMultiShipOrderDatalst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectShipOrderDatalst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipOrderDatalst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterSelectShipOrderDatalst(party router.Party, path string, method func(*models.Usertab, map[string]string) ([]model.ShipOrderDatalst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryShipOrderDatalst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipOrderDatalst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterQueryShipOrderDatalst(party router.Party, path string, method func(*models.Usertab, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateShipOrderDatalst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ShipOrderDatalst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterUpdateShipOrderDatalst(party router.Party, path string, method func(*models.Usertab, *[]model.ShipOrderDatalst) error) {

	RegisterMultiShipOrderDatalst(party, "PUT", path, method)
}
