// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package jit

import (
	"LAPP_GAAS_GFrame_BACKEND/grmi"
	model "LAPP_GAAS_GFrame_BACKEND/models/jit"
	"LAPP_GAAS_GFrame_BACKEND/web/middleware/jwts"
	"LAPP_GAAS_GFrame_BACKEND/web/models"
	"LAPP_GAAS_GFrame_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneShipOrderItemlst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ShipOrderItemlst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterOneShipOrderItemlst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ShipOrderItemlst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ShipOrderItemlst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfShipOrderItemlst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ShipOrderItemlst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterIDOfShipOrderItemlst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		shipOrderId := ctx.Params().GetString("shipOrderId")
		itemId := ctx.Params().GetString("itemId")

		err = method(user, shipOrderId, itemId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneShipOrderItemlst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ShipOrderItemlst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterInsertOneShipOrderItemlst(party router.Party, path string, method func(*models.Usertab, *model.ShipOrderItemlst) error) {

	RegisterOneShipOrderItemlst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneShipOrderItemlst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ShipOrderItemlst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterDeleteOneShipOrderItemlst(party router.Party, path string, method func(*models.Usertab, string, string) error) {

	RegisterIDOfShipOrderItemlst(party, "DELETE", path+"/{shipOrderId:string}/{itemId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneShipOrderItemlst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ShipOrderItemlst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterSelectOneShipOrderItemlst(party router.Party, path string, method func(*models.Usertab, string, string) (*model.ShipOrderItemlst, error)) {

	party.Get(path+"/{shipOrderId:string}/{itemId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		shipOrderId := ctx.Params().GetString("shipOrderId")
		itemId := ctx.Params().GetString("itemId")
		result, err := method(user, shipOrderId, itemId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneShipOrderItemlst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ShipOrderItemlst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterUpdateOneShipOrderItemlst(party router.Party, path string, method func(*models.Usertab, *model.ShipOrderItemlst) error) {

	RegisterOneShipOrderItemlst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiShipOrderItemlst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ShipOrderItemlst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterMultiShipOrderItemlst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ShipOrderItemlst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ShipOrderItemlst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertShipOrderItemlst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ShipOrderItemlst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterInsertShipOrderItemlst(party router.Party, path string, method func(*models.Usertab, *[]model.ShipOrderItemlst) error) {

	RegisterMultiShipOrderItemlst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteShipOrderItemlst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ShipOrderItemlst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterDeleteShipOrderItemlst(party router.Party, path string, method func(*models.Usertab, *[]model.ShipOrderItemlst) error) {

	RegisterMultiShipOrderItemlst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectShipOrderItemlst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipOrderItemlst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterSelectShipOrderItemlst(party router.Party, path string, method func(*models.Usertab, map[string]string) ([]model.ShipOrderItemlst, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryShipOrderItemlst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ShipOrderItemlst并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterQueryShipOrderItemlst(party router.Party, path string, method func(*models.Usertab, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateShipOrderItemlst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ShipOrderItemlst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-25 13:36:01
 *
 ******************************************************************************/
func RegisterUpdateShipOrderItemlst(party router.Party, path string, method func(*models.Usertab, *[]model.ShipOrderItemlst) error) {

	RegisterMultiShipOrderItemlst(party, "PUT", path, method)
}
